from typing import TYPE_CHECKING

from yandexcloud._wrappers.dataproc import Dataproc, InitializationAction
from yandexcloud._wrappers.spark import (
    PysparkJobParameters,
    Spark,
    SparkClusterParameters,
    SparkJobParameters,
)

if TYPE_CHECKING:
    from yandexcloud._sdk import SDK


class Wrappers:
    def __init__(self, sdk: "SDK"):
        # pylint: disable-next=invalid-name
        self.Dataproc = Dataproc
        self.Dataproc.sdk = sdk
        # pylint: disable-next=invalid-name
        self.InitializationAction = InitializationAction
        # pylint: disable-next=invalid-name
        self.Spark = Spark
        # pylint: disable-next=invalid-name
        self.SparkClusterParameters = SparkClusterParameters
        # pylint: disable-next=invalid-name
        self.SparkJobParameters = SparkJobParameters
        # pylint: disable-next=invalid-name
        self.PysparkJobParameters = PysparkJobParameters
        self.Spark.sdk = sdk



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/test/test.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/test/test.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import single_agent_configuration_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_single__agent__configuration__pb2
from yandex.cloud.loadtesting.api.v1.test import details_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_details__pb2
from yandex.cloud.loadtesting.api.v1.test import summary_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/loadtesting/api/v1/test/test.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x45yandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto\x1a\x32yandex/cloud/loadtesting/api/v1/test/details.proto\x1a\x32yandex/cloud/loadtesting/api/v1/test/summary.proto\"\xfd\x01\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x0e\x63onfigurations\x18\x02 \x03(\x0b\x32>.yandex.cloud.loadtesting.api.v1.test.SingleAgentConfiguration\x12>\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32-.yandex.cloud.loadtesting.api.v1.test.Details\x12>\n\x07summary\x18\x04 \x01(\x0b\x32-.yandex.cloud.loadtesting.api.v1.test.Summary\x12\x11\n\tfolder_id\x18\x05 \x01(\tBy\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.test_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_TEST']._serialized_start=265
  _globals['_TEST']._serialized_end=518
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.backup.v1.policy_pb2
import yandex.cloud.backup.v1.policy_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PolicyServiceStub:
    """A set of methods for managing [policies](/docs/backup/concepts/policy)."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesRequest,
        yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesResponse,
    ]
    """List [policies](/docs/backup/concepts/policy) of specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.CreatePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create a new policy.

    For detailed information, please see [Creating a backup policy](/docs/backup/operations/policy-vm/create).
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.GetPolicyRequest,
        yandex.cloud.backup.v1.policy_pb2.Policy,
    ]
    """Get specific policy."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.UpdatePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update specific policy."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.DeletePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific policy."""

    Apply: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ApplyPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Apply policy to [Compute Cloud instance](/docs/backup/concepts/vm-connection#os)."""

    ListApplications: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsRequest,
        yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsResponse,
    ]
    """List applied policies using filters."""

    Execute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ExecuteRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Run policy on specific Compute Cloud instance. That will create backup
    according selected policy. In order to perform this action, policy should be
    applied to the Compute Cloud instance.
    """

    Revoke: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.RevokeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Revoke policy from Compute Cloud instance."""

class PolicyServiceAsyncStub:
    """A set of methods for managing [policies](/docs/backup/concepts/policy)."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesRequest,
        yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesResponse,
    ]
    """List [policies](/docs/backup/concepts/policy) of specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.CreatePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create a new policy.

    For detailed information, please see [Creating a backup policy](/docs/backup/operations/policy-vm/create).
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.GetPolicyRequest,
        yandex.cloud.backup.v1.policy_pb2.Policy,
    ]
    """Get specific policy."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.UpdatePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update specific policy."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.DeletePolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specific policy."""

    Apply: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ApplyPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Apply policy to [Compute Cloud instance](/docs/backup/concepts/vm-connection#os)."""

    ListApplications: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsRequest,
        yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsResponse,
    ]
    """List applied policies using filters."""

    Execute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.ExecuteRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Run policy on specific Compute Cloud instance. That will create backup
    according selected policy. In order to perform this action, policy should be
    applied to the Compute Cloud instance.
    """

    Revoke: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.policy_service_pb2.RevokeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Revoke policy from Compute Cloud instance."""

class PolicyServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [policies](/docs/backup/concepts/policy)."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.policy_service_pb2.ListPoliciesResponse]]:
        """List [policies](/docs/backup/concepts/policy) of specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.CreatePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create a new policy.

        For detailed information, please see [Creating a backup policy](/docs/backup/operations/policy-vm/create).
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.GetPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.policy_pb2.Policy, collections.abc.Awaitable[yandex.cloud.backup.v1.policy_pb2.Policy]]:
        """Get specific policy."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.UpdatePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update specific policy."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.DeletePolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specific policy."""

    @abc.abstractmethod
    def Apply(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.ApplyPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Apply policy to [Compute Cloud instance](/docs/backup/concepts/vm-connection#os)."""

    @abc.abstractmethod
    def ListApplications(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.policy_service_pb2.ListApplicationsResponse]]:
        """List applied policies using filters."""

    @abc.abstractmethod
    def Execute(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.ExecuteRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Run policy on specific Compute Cloud instance. That will create backup
        according selected policy. In order to perform this action, policy should be
        applied to the Compute Cloud instance.
        """

    @abc.abstractmethod
    def Revoke(
        self,
        request: yandex.cloud.backup.v1.policy_service_pb2.RevokeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Revoke policy from Compute Cloud instance."""

def add_PolicyServiceServicer_to_server(servicer: PolicyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Test(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Test._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Test._Status.ValueType  # 0
        CREATED: Test._Status.ValueType  # 1
        INITIATED: Test._Status.ValueType  # 2
        PREPARING: Test._Status.ValueType  # 3
        RUNNING: Test._Status.ValueType  # 4
        FINISHING: Test._Status.ValueType  # 5
        DONE: Test._Status.ValueType  # 6
        POST_PROCESSING: Test._Status.ValueType  # 7
        FAILED: Test._Status.ValueType  # 8
        STOPPING: Test._Status.ValueType  # 9
        STOPPED: Test._Status.ValueType  # 10
        AUTOSTOPPED: Test._Status.ValueType  # 11
        WAITING: Test._Status.ValueType  # 12
        DELETING: Test._Status.ValueType  # 13
        LOST: Test._Status.ValueType  # 14
        CANCELLED: Test._Status.ValueType  # 15

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Test.Status.ValueType  # 0
    CREATED: Test.Status.ValueType  # 1
    INITIATED: Test.Status.ValueType  # 2
    PREPARING: Test.Status.ValueType  # 3
    RUNNING: Test.Status.ValueType  # 4
    FINISHING: Test.Status.ValueType  # 5
    DONE: Test.Status.ValueType  # 6
    POST_PROCESSING: Test.Status.ValueType  # 7
    FAILED: Test.Status.ValueType  # 8
    STOPPING: Test.Status.ValueType  # 9
    STOPPED: Test.Status.ValueType  # 10
    AUTOSTOPPED: Test.Status.ValueType  # 11
    WAITING: Test.Status.ValueType  # 12
    DELETING: Test.Status.ValueType  # 13
    LOST: Test.Status.ValueType  # 14
    CANCELLED: Test.Status.ValueType  # 15

    class _Generator:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GeneratorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Test._Generator.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GENERATOR_UNSPECIFIED: Test._Generator.ValueType  # 0
        PANDORA: Test._Generator.ValueType  # 1
        PHANTOM: Test._Generator.ValueType  # 2
        JMETER: Test._Generator.ValueType  # 3

    class Generator(_Generator, metaclass=_GeneratorEnumTypeWrapper): ...
    GENERATOR_UNSPECIFIED: Test.Generator.ValueType  # 0
    PANDORA: Test.Generator.ValueType  # 1
    PHANTOM: Test.Generator.ValueType  # 2
    JMETER: Test.Generator.ValueType  # 3

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    GENERATOR_FIELD_NUMBER: builtins.int
    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    TARGET_ADDRESS_FIELD_NUMBER: builtins.int
    TARGET_PORT_FIELD_NUMBER: builtins.int
    TARGET_VERSION_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    AMMO_URLS_FIELD_NUMBER: builtins.int
    AMMO_ID_FIELD_NUMBER: builtins.int
    CASES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    id: builtins.str
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    generator: global___Test.Generator.ValueType
    agent_instance_id: builtins.str
    """AgentInstance ID where Test is running."""
    target_address: builtins.str
    """Target VM."""
    target_port: builtins.int
    target_version: builtins.str
    """Version of object under test."""
    config: builtins.str
    """Test details"""
    ammo_urls: builtins.str
    ammo_id: builtins.str
    status: global___Test.Status.ValueType
    favorite: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def finished_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def cases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finished_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        generator: global___Test.Generator.ValueType = ...,
        agent_instance_id: builtins.str = ...,
        target_address: builtins.str = ...,
        target_port: builtins.int = ...,
        target_version: builtins.str = ...,
        config: builtins.str = ...,
        ammo_urls: builtins.str = ...,
        ammo_id: builtins.str = ...,
        cases: collections.abc.Iterable[builtins.str] | None = ...,
        status: global___Test.Status.ValueType = ...,
        errors: collections.abc.Iterable[builtins.str] | None = ...,
        favorite: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ammo", b"ammo", "ammo_id", b"ammo_id", "ammo_urls", b"ammo_urls", "created_at", b"created_at", "finished_at", b"finished_at", "started_at", b"started_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "ammo", b"ammo", "ammo_id", b"ammo_id", "ammo_urls", b"ammo_urls", "cases", b"cases", "config", b"config", "created_at", b"created_at", "description", b"description", "errors", b"errors", "favorite", b"favorite", "finished_at", b"finished_at", "folder_id", b"folder_id", "generator", b"generator", "id", b"id", "labels", b"labels", "name", b"name", "started_at", b"started_at", "status", b"status", "target_address", b"target_address", "target_port", b"target_port", "target_version", b"target_version", "updated_at", b"updated_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ammo", b"ammo"]) -> typing.Literal["ammo_urls", "ammo_id"] | None: ...

global___Test = Test



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cloudrouter.v1.routing_instance_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetRoutingInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource to return.
    To get the routingInstance ID use a [RoutingInstanceService.List] request.
    """
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id"]) -> None: ...

global___GetRoutingInstanceRequest = GetRoutingInstanceRequest

@typing.final
class GetRoutingInstanceByCicPrivateConnectionIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIC_PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    cic_private_connection_id: builtins.str
    """ID of the PrivateConnection resource to return by.
    To get the routingInstance ID use a [RoutingInstanceService.List] request.
    """
    def __init__(
        self,
        *,
        cic_private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_id", b"cic_private_connection_id"]) -> None: ...

global___GetRoutingInstanceByCicPrivateConnectionIdRequest = GetRoutingInstanceByCicPrivateConnectionIdRequest

@typing.final
class GetRoutingInstanceByVpcNetworkIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
    vpc_network_id: builtins.str
    """ID of the VpcNetwork resource to return by.
    To get the routingInstance ID use a [RoutingInstanceService.List] request.
    """
    def __init__(
        self,
        *,
        vpc_network_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vpc_network_id", b"vpc_network_id"]) -> None: ...

global___GetRoutingInstanceByVpcNetworkIdRequest = GetRoutingInstanceByVpcNetworkIdRequest

@typing.final
class ListRoutingInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list RoutingInstance resources.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRoutingInstancesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRoutingInstanceResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [RoutingInstance.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListRoutingInstancesRequest = ListRoutingInstancesRequest

@typing.final
class ListRoutingInstancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRoutingInstancesResponse.page_size], use
    the [next_page_token] as the value
    for the [ListRoutingInstanceResponses.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def routing_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]:
        """List of RoutingInstance resources."""

    def __init__(
        self,
        *,
        routing_instances: collections.abc.Iterable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "routing_instances", b"routing_instances"]) -> None: ...

global___ListRoutingInstancesResponse = ListRoutingInstancesResponse

@typing.final
class CreateRoutingInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    VPC_INFO_FIELD_NUMBER: builtins.int
    CIC_PRIVATE_CONNECTION_INFO_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the RoutingInstance.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the RoutingInstance. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the RoutingInstance belongs to."""
    region_id: builtins.str
    """ID of the region that the routingInstance belongs to."""
    @property
    def vpc_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.VpcInfo]:
        """List of the info about vpcNetworks which are attached to the RoutingInstance."""

    @property
    def cic_private_connection_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.CicPrivateConnectionInfo]:
        """List of the info about privateConnections which are attached to the RoutingInstance."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        vpc_info: collections.abc.Iterable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.VpcInfo] | None = ...,
        cic_private_connection_info: collections.abc.Iterable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.CicPrivateConnectionInfo] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_info", b"cic_private_connection_info", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "region_id", b"region_id", "vpc_info", b"vpc_info"]) -> None: ...

global___CreateRoutingInstanceRequest = CreateRoutingInstanceRequest

@typing.final
class CreateRoutingInstanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id"]) -> None: ...

global___CreateRoutingInstanceMetadata = CreateRoutingInstanceMetadata

@typing.final
class UpdateRoutingInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    VPC_INFO_FIELD_NUMBER: builtins.int
    CIC_PRIVATE_CONNECTION_INFO_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource to return."""
    name: builtins.str
    """Name of the RoutingInstance.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the RoutingInstance. 0-256 characters long."""
    region_id: builtins.str
    """ID of the region that the routingInstance belongs to."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the RoutingInstance resource are going to be updated."""

    @property
    def vpc_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.VpcInfo]:
        """List of the info about vpcNetworks which are attached to the RoutingInstance."""

    @property
    def cic_private_connection_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.CicPrivateConnectionInfo]:
        """List of the info about privateConnections which are attached to the RoutingInstance."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        region_id: builtins.str = ...,
        vpc_info: collections.abc.Iterable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.VpcInfo] | None = ...,
        cic_private_connection_info: collections.abc.Iterable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance.CicPrivateConnectionInfo] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_info", b"cic_private_connection_info", "description", b"description", "labels", b"labels", "name", b"name", "region_id", b"region_id", "routing_instance_id", b"routing_instance_id", "update_mask", b"update_mask", "vpc_info", b"vpc_info"]) -> None: ...

global___UpdateRoutingInstanceRequest = UpdateRoutingInstanceRequest

@typing.final
class UpdateRoutingInstanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id"]) -> None: ...

global___UpdateRoutingInstanceMetadata = UpdateRoutingInstanceMetadata

@typing.final
class UpsertPrefixesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
    VPC_AZ_INFO_PREFIXES_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    vpc_network_id: builtins.str
    """ID of the VpcNetwork to update."""
    @property
    def vpc_az_info_prefixes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VpcAzInfoPrefixes]:
        """List of VpcAzInfoPrefixes to upsert."""

    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        vpc_network_id: builtins.str = ...,
        vpc_az_info_prefixes: collections.abc.Iterable[global___VpcAzInfoPrefixes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id", "vpc_az_info_prefixes", b"vpc_az_info_prefixes", "vpc_network_id", b"vpc_network_id"]) -> None: ...

global___UpsertPrefixesRequest = UpsertPrefixesRequest

@typing.final
class RemovePrefixesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
    VPC_AZ_INFO_PREFIXES_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    vpc_network_id: builtins.str
    """ID of the VpcNetwork to update."""
    @property
    def vpc_az_info_prefixes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VpcAzInfoPrefixes]:
        """List of VpcAzInfoPrefixes to remove."""

    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        vpc_network_id: builtins.str = ...,
        vpc_az_info_prefixes: collections.abc.Iterable[global___VpcAzInfoPrefixes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id", "vpc_az_info_prefixes", b"vpc_az_info_prefixes", "vpc_network_id", b"vpc_network_id"]) -> None: ...

global___RemovePrefixesRequest = RemovePrefixesRequest

@typing.final
class VpcAzInfoPrefixes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZ_ID_FIELD_NUMBER: builtins.int
    PREFIXES_FIELD_NUMBER: builtins.int
    az_id: builtins.str
    """ID of the AZ."""
    @property
    def prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of prefixes."""

    def __init__(
        self,
        *,
        az_id: builtins.str = ...,
        prefixes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["az_id", b"az_id", "prefixes", b"prefixes"]) -> None: ...

global___VpcAzInfoPrefixes = VpcAzInfoPrefixes

@typing.final
class MovePrefixRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    SRC_VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
    SRC_AZ_ID_FIELD_NUMBER: builtins.int
    DST_VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
    DST_AZ_ID_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    src_vpc_network_id: builtins.str
    """ID of the source VpcNetwork."""
    src_az_id: builtins.str
    """ID of the AZ in the source VpcNetwork."""
    dst_vpc_network_id: builtins.str
    """ID of the destination VpcNetwork."""
    dst_az_id: builtins.str
    """ID of the AZ in the destination VpcNetwork."""
    prefix: builtins.str
    """Prefix to move."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        src_vpc_network_id: builtins.str = ...,
        src_az_id: builtins.str = ...,
        dst_vpc_network_id: builtins.str = ...,
        dst_az_id: builtins.str = ...,
        prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dst_az_id", b"dst_az_id", "dst_vpc_network_id", b"dst_vpc_network_id", "prefix", b"prefix", "routing_instance_id", b"routing_instance_id", "src_az_id", b"src_az_id", "src_vpc_network_id", b"src_vpc_network_id"]) -> None: ...

global___MovePrefixRequest = MovePrefixRequest

@typing.final
class UpdatePrefixMaskRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
    AZ_ID_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    NEW_MASK_FIELD_NUMBER: builtins.int
    REMOVE_SUB_PREFIXES_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    vpc_network_id: builtins.str
    """ID of the VpcNetwork."""
    az_id: builtins.str
    """ID of the AZ"""
    prefix: builtins.str
    """Prefix to update mask"""
    new_mask: builtins.int
    """The new mask"""
    remove_sub_prefixes: builtins.bool
    """Specifies whether existing sub-prefixes covered by the mask should be removed."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        vpc_network_id: builtins.str = ...,
        az_id: builtins.str = ...,
        prefix: builtins.str = ...,
        new_mask: builtins.int = ...,
        remove_sub_prefixes: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["az_id", b"az_id", "new_mask", b"new_mask", "prefix", b"prefix", "remove_sub_prefixes", b"remove_sub_prefixes", "routing_instance_id", b"routing_instance_id", "vpc_network_id", b"vpc_network_id"]) -> None: ...

global___UpdatePrefixMaskRequest = UpdatePrefixMaskRequest

@typing.final
class AddPrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    CIC_PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    cic_private_connection_id: builtins.str
    """ID of the PrivateConnection to add to the RoutingInstance."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        cic_private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_id", b"cic_private_connection_id", "routing_instance_id", b"routing_instance_id"]) -> None: ...

global___AddPrivateConnectionRequest = AddPrivateConnectionRequest

@typing.final
class RemovePrivateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    CIC_PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    cic_private_connection_id: builtins.str
    """ID of the PrivateConnection to remove from the RoutingInstance."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        cic_private_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_id", b"cic_private_connection_id", "routing_instance_id", b"routing_instance_id"]) -> None: ...

global___RemovePrivateConnectionRequest = RemovePrivateConnectionRequest

@typing.final
class DeleteRoutingInstanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id"]) -> None: ...

global___DeleteRoutingInstanceRequest = DeleteRoutingInstanceRequest

@typing.final
class DeleteRoutingInstanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id"]) -> None: ...

global___DeleteRoutingInstanceMetadata = DeleteRoutingInstanceMetadata

@typing.final
class ListRoutingInstanceOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of the RoutingInstance resource."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRoutingInstanceOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests. Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListRoutingInstanceOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "routing_instance_id", b"routing_instance_id"]) -> None: ...

global___ListRoutingInstanceOperationsRequest = ListRoutingInstanceOperationsRequest

@typing.final
class ListRoutingInstanceOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRoutingInstanceOperationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListRoutingInstanceOperationsRequest.page_token] query parameter
    in the next list request. Subsequent list requests will have their own
    [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of RoutingInstance operations."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListRoutingInstanceOperationsResponse = ListRoutingInstanceOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.ai.assistants.v1.common_pb2
import yandex.cloud.ai.common.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Thread(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_AUTHOR_ID_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_BY_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the thread."""
    folder_id: builtins.str
    """ID of the folder that the thread belongs to."""
    name: builtins.str
    """Name of the thread."""
    description: builtins.str
    """Description of the thread."""
    default_message_author_id: builtins.str
    """Default user ID that will be used as the author for thread messages if no other author is specified."""
    created_by: builtins.str
    """Identifier of the subject who created this thread."""
    updated_by: builtins.str
    """Identifier of the subject who last updated this thread."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the thread was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing the last time this thread was updated."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """Configuration for the expiration of the thread, defining when and how the thread will expire."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the thread will expire."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs that can be used to organize and categorize the thread."""

    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.common_pb2.Tool]:
        """List of tools that are available for assistants to use in this thread."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        default_message_author_id: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_by: builtins.str = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tools: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.common_pb2.Tool] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "expiration_config", b"expiration_config", "expires_at", b"expires_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "default_message_author_id", b"default_message_author_id", "description", b"description", "expiration_config", b"expiration_config", "expires_at", b"expires_at", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "tools", b"tools", "updated_at", b"updated_at", "updated_by", b"updated_by"]) -> None: ...

global___Thread = Thread



from yandexcloud._auth_fabric import get_auth_token_requester

from .metadata_server_mock import metadata_server


def test_metadata_auth(iam_token):
    with metadata_server(iam_token) as srv:
        requester = get_auth_token_requester(metadata_addr=srv.addr)
        token = requester.get_token()
        assert token == iam_token



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _YdbCleanupPolicy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _YdbCleanupPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_YdbCleanupPolicy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    YDB_CLEANUP_POLICY_UNSPECIFIED: _YdbCleanupPolicy.ValueType  # 0
    YDB_CLEANUP_POLICY_DISABLED: _YdbCleanupPolicy.ValueType  # 1
    YDB_CLEANUP_POLICY_DROP: _YdbCleanupPolicy.ValueType  # 2

class YdbCleanupPolicy(_YdbCleanupPolicy, metaclass=_YdbCleanupPolicyEnumTypeWrapper): ...

YDB_CLEANUP_POLICY_UNSPECIFIED: YdbCleanupPolicy.ValueType  # 0
YDB_CLEANUP_POLICY_DISABLED: YdbCleanupPolicy.ValueType  # 1
YDB_CLEANUP_POLICY_DROP: YdbCleanupPolicy.ValueType  # 2
global___YdbCleanupPolicy = YdbCleanupPolicy

class _YdbDefaultCompression:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _YdbDefaultCompressionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_YdbDefaultCompression.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    YDB_DEFAULT_COMPRESSION_UNSPECIFIED: _YdbDefaultCompression.ValueType  # 0
    YDB_DEFAULT_COMPRESSION_DISABLED: _YdbDefaultCompression.ValueType  # 1
    YDB_DEFAULT_COMPRESSION_LZ4: _YdbDefaultCompression.ValueType  # 2

class YdbDefaultCompression(_YdbDefaultCompression, metaclass=_YdbDefaultCompressionEnumTypeWrapper): ...

YDB_DEFAULT_COMPRESSION_UNSPECIFIED: YdbDefaultCompression.ValueType  # 0
YDB_DEFAULT_COMPRESSION_DISABLED: YdbDefaultCompression.ValueType  # 1
YDB_DEFAULT_COMPRESSION_LZ4: YdbDefaultCompression.ValueType  # 2
global___YdbDefaultCompression = YdbDefaultCompression

@typing.final
class YdbSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SA_KEY_CONTENT_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    CHANGEFEED_CUSTOM_NAME_FIELD_NUMBER: builtins.int
    CHANGEFEED_CUSTOM_CONSUMER_NAME_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Path in YDB where to store tables"""
    instance: builtins.str
    """Instance of YDB. example: ydb-ru-prestable.yandex.net:2135"""
    service_account_id: builtins.str
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    sa_key_content: builtins.str
    """Authorization Key"""
    changefeed_custom_name: builtins.str
    """Pre-created change feed"""
    changefeed_custom_consumer_name: builtins.str
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        database: builtins.str = ...,
        instance: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        sa_key_content: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        changefeed_custom_name: builtins.str = ...,
        changefeed_custom_consumer_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["changefeed_custom_consumer_name", b"changefeed_custom_consumer_name", "changefeed_custom_name", b"changefeed_custom_name", "database", b"database", "instance", b"instance", "paths", b"paths", "sa_key_content", b"sa_key_content", "security_groups", b"security_groups", "service_account_id", b"service_account_id", "subnet_id", b"subnet_id"]) -> None: ...

global___YdbSource = YdbSource

@typing.final
class YdbTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SA_KEY_CONTENT_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    IS_TABLE_COLUMN_ORIENTED_FIELD_NUMBER: builtins.int
    DEFAULT_COMPRESSION_FIELD_NUMBER: builtins.int
    IS_SCHEMA_MIGRATION_DISABLED_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Path in YDB where to store tables"""
    instance: builtins.str
    """Instance of YDB. example: ydb-ru-prestable.yandex.net:2135"""
    path: builtins.str
    """Path extension for database, each table will be layouted into this path"""
    service_account_id: builtins.str
    cleanup_policy: global___YdbCleanupPolicy.ValueType
    """Cleanup policy"""
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    sa_key_content: builtins.str
    """SA content"""
    is_table_column_oriented: builtins.bool
    """Should create column-oriented table (OLAP). By default it creates row-oriented
    (OLTP)
    """
    default_compression: global___YdbDefaultCompression.ValueType
    """Compression that will be used for default columns family on YDB table creation"""
    is_schema_migration_disabled: builtins.bool
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        database: builtins.str = ...,
        instance: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
        cleanup_policy: global___YdbCleanupPolicy.ValueType = ...,
        subnet_id: builtins.str = ...,
        sa_key_content: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_table_column_oriented: builtins.bool = ...,
        default_compression: global___YdbDefaultCompression.ValueType = ...,
        is_schema_migration_disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "database", b"database", "default_compression", b"default_compression", "instance", b"instance", "is_schema_migration_disabled", b"is_schema_migration_disabled", "is_table_column_oriented", b"is_table_column_oriented", "path", b"path", "sa_key_content", b"sa_key_content", "security_groups", b"security_groups", "service_account_id", b"service_account_id", "subnet_id", b"subnet_id"]) -> None: ...

global___YdbTarget = YdbTarget



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/vpc/v1/route_table_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/vpc/v1/route_table_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.vpc.v1 import route_table_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_route__table__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/vpc/v1/route_table_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a%yandex/cloud/vpc/v1/route_table.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"<\n\x14GetRouteTableRequest\x12$\n\x0eroute_table_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x93\x01\n\x16ListRouteTablesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"i\n\x17ListRouteTablesResponse\x12\x35\n\x0croute_tables\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.vpc.v1.RouteTable\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xaa\x03\n\x17\x43reateRouteTableRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x85\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x38.yandex.cloud.vpc.v1.CreateRouteTableRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12 \n\nnetwork_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x37\n\rstatic_routes\x18\x06 \x03(\x0b\x32 .yandex.cloud.vpc.v1.StaticRoute\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x18\x43reateRouteTableMetadata\x12\x16\n\x0eroute_table_id\x18\x01 \x01(\t\"\xbe\x03\n\x17UpdateRouteTableRequest\x12$\n\x0eroute_table_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04name\x18\x03 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x38.yandex.cloud.vpc.v1.UpdateRouteTableRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x37\n\rstatic_routes\x18\x06 \x03(\x0b\x32 .yandex.cloud.vpc.v1.StaticRoute\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x18UpdateRouteTableMetadata\x12\x16\n\x0eroute_table_id\x18\x01 \x01(\t\"?\n\x17\x44\x65leteRouteTableRequest\x12$\n\x0eroute_table_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x18\x44\x65leteRouteTableMetadata\x12\x16\n\x0eroute_table_id\x18\x01 \x01(\t\"\x85\x01\n\x1fListRouteTableOperationsRequest\x12$\n\x0eroute_table_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"r\n ListRouteTableOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"j\n\x15MoveRouteTableRequest\x12$\n\x0eroute_table_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"0\n\x16MoveRouteTableMetadata\x12\x16\n\x0eroute_table_id\x18\x01 \x01(\t2\x9f\t\n\x11RouteTableService\x12\x7f\n\x03Get\x12).yandex.cloud.vpc.v1.GetRouteTableRequest\x1a\x1f.yandex.cloud.vpc.v1.RouteTable\",\x82\xd3\xe4\x93\x02&\x12$/vpc/v1/routeTables/{route_table_id}\x12~\n\x04List\x12+.yandex.cloud.vpc.v1.ListRouteTablesRequest\x1a,.yandex.cloud.vpc.v1.ListRouteTablesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/vpc/v1/routeTables\x12\xa3\x01\n\x06\x43reate\x12,.yandex.cloud.vpc.v1.CreateRouteTableRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*&\n\x18\x43reateRouteTableMetadata\x12\nRouteTable\x82\xd3\xe4\x93\x02\x18\"\x13/vpc/v1/routeTables:\x01*\x12\xb4\x01\n\x06Update\x12,.yandex.cloud.vpc.v1.UpdateRouteTableRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*&\n\x18UpdateRouteTableMetadata\x12\nRouteTable\x82\xd3\xe4\x93\x02)2$/vpc/v1/routeTables/{route_table_id}:\x01*\x12\xbc\x01\n\x06\x44\x65lete\x12,.yandex.cloud.vpc.v1.DeleteRouteTableRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*1\n\x18\x44\x65leteRouteTableMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/vpc/v1/routeTables/{route_table_id}\x12\xb6\x01\n\x0eListOperations\x12\x34.yandex.cloud.vpc.v1.ListRouteTableOperationsRequest\x1a\x35.yandex.cloud.vpc.v1.ListRouteTableOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//vpc/v1/routeTables/{route_table_id}/operations\x12\xb3\x01\n\x04Move\x12*.yandex.cloud.vpc.v1.MoveRouteTableRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*$\n\x16MoveRouteTableMetadata\x12\nRouteTable\x82\xd3\xe4\x93\x02.\")/vpc/v1/routeTables/{route_table_id}:move:\x01*BV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.route_table_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _globals['_GETROUTETABLEREQUEST'].fields_by_name['route_table_id']._loaded_options = None
  _globals['_GETROUTETABLEREQUEST'].fields_by_name['route_table_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEROUTETABLEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEROUTETABLEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEROUTETABLEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEROUTETABLEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['route_table_id']._loaded_options = None
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['route_table_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEROUTETABLEREQUEST'].fields_by_name['route_table_id']._loaded_options = None
  _globals['_DELETEROUTETABLEREQUEST'].fields_by_name['route_table_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTETABLEOPERATIONSREQUEST'].fields_by_name['route_table_id']._loaded_options = None
  _globals['_LISTROUTETABLEOPERATIONSREQUEST'].fields_by_name['route_table_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTETABLEOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTROUTETABLEOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTROUTETABLEOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTROUTETABLEOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_MOVEROUTETABLEREQUEST'].fields_by_name['route_table_id']._loaded_options = None
  _globals['_MOVEROUTETABLEREQUEST'].fields_by_name['route_table_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MOVEROUTETABLEREQUEST'].fields_by_name['destination_folder_id']._loaded_options = None
  _globals['_MOVEROUTETABLEREQUEST'].fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ROUTETABLESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/vpc/v1/routeTables/{route_table_id}'
  _globals['_ROUTETABLESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/vpc/v1/routeTables'
  _globals['_ROUTETABLESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateRouteTableMetadata\022\nRouteTable\202\323\344\223\002\030\"\023/vpc/v1/routeTables:\001*'
  _globals['_ROUTETABLESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateRouteTableMetadata\022\nRouteTable\202\323\344\223\002)2$/vpc/v1/routeTables/{route_table_id}:\001*'
  _globals['_ROUTETABLESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteRouteTableMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/vpc/v1/routeTables/{route_table_id}'
  _globals['_ROUTETABLESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0021\022//vpc/v1/routeTables/{route_table_id}/operations'
  _globals['_ROUTETABLESERVICE'].methods_by_name['Move']._loaded_options = None
  _globals['_ROUTETABLESERVICE'].methods_by_name['Move']._serialized_options = b'\262\322*$\n\026MoveRouteTableMetadata\022\nRouteTable\202\323\344\223\002.\")/vpc/v1/routeTables/{route_table_id}:move:\001*'
  _globals['_GETROUTETABLEREQUEST']._serialized_start=278
  _globals['_GETROUTETABLEREQUEST']._serialized_end=338
  _globals['_LISTROUTETABLESREQUEST']._serialized_start=341
  _globals['_LISTROUTETABLESREQUEST']._serialized_end=488
  _globals['_LISTROUTETABLESRESPONSE']._serialized_start=490
  _globals['_LISTROUTETABLESRESPONSE']._serialized_end=595
  _globals['_CREATEROUTETABLEREQUEST']._serialized_start=598
  _globals['_CREATEROUTETABLEREQUEST']._serialized_end=1024
  _globals['_CREATEROUTETABLEREQUEST_LABELSENTRY']._serialized_start=979
  _globals['_CREATEROUTETABLEREQUEST_LABELSENTRY']._serialized_end=1024
  _globals['_CREATEROUTETABLEMETADATA']._serialized_start=1026
  _globals['_CREATEROUTETABLEMETADATA']._serialized_end=1076
  _globals['_UPDATEROUTETABLEREQUEST']._serialized_start=1079
  _globals['_UPDATEROUTETABLEREQUEST']._serialized_end=1525
  _globals['_UPDATEROUTETABLEREQUEST_LABELSENTRY']._serialized_start=979
  _globals['_UPDATEROUTETABLEREQUEST_LABELSENTRY']._serialized_end=1024
  _globals['_UPDATEROUTETABLEMETADATA']._serialized_start=1527
  _globals['_UPDATEROUTETABLEMETADATA']._serialized_end=1577
  _globals['_DELETEROUTETABLEREQUEST']._serialized_start=1579
  _globals['_DELETEROUTETABLEREQUEST']._serialized_end=1642
  _globals['_DELETEROUTETABLEMETADATA']._serialized_start=1644
  _globals['_DELETEROUTETABLEMETADATA']._serialized_end=1694
  _globals['_LISTROUTETABLEOPERATIONSREQUEST']._serialized_start=1697
  _globals['_LISTROUTETABLEOPERATIONSREQUEST']._serialized_end=1830
  _globals['_LISTROUTETABLEOPERATIONSRESPONSE']._serialized_start=1832
  _globals['_LISTROUTETABLEOPERATIONSRESPONSE']._serialized_end=1946
  _globals['_MOVEROUTETABLEREQUEST']._serialized_start=1948
  _globals['_MOVEROUTETABLEREQUEST']._serialized_end=2054
  _globals['_MOVEROUTETABLEMETADATA']._serialized_start=2056
  _globals['_MOVEROUTETABLEMETADATA']._serialized_end=2104
  _globals['_ROUTETABLESERVICE']._serialized_start=2107
  _globals['_ROUTETABLESERVICE']._serialized_end=3290
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DiskDriveType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DiskDriveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DiskDriveType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DISK_DRIVE_TYPE_UNSPECIFIED: _DiskDriveType.ValueType  # 0
    """Unspecified disk drive type."""
    HDD: _DiskDriveType.ValueType  # 1
    """Hard disk drive (magnetic storage)."""
    SSD: _DiskDriveType.ValueType  # 2
    """Solid state drive with SATA/SAS interface."""
    NVME: _DiskDriveType.ValueType  # 3
    """Solid state drive with NVMe interface."""

class DiskDriveType(_DiskDriveType, metaclass=_DiskDriveTypeEnumTypeWrapper):
    """Disk drive type."""

DISK_DRIVE_TYPE_UNSPECIFIED: DiskDriveType.ValueType  # 0
"""Unspecified disk drive type."""
HDD: DiskDriveType.ValueType  # 1
"""Hard disk drive (magnetic storage)."""
SSD: DiskDriveType.ValueType  # 2
"""Solid state drive with SATA/SAS interface."""
NVME: DiskDriveType.ValueType  # 3
"""Solid state drive with NVMe interface."""
global___DiskDriveType = DiskDriveType

@typing.final
class Disk(google.protobuf.message.Message):
    """Disk."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SIZE_GIB_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the disk."""
    type: global___DiskDriveType.ValueType
    """Type of the disk drive."""
    size_gib: builtins.int
    """Size of the disk in gibibytes (2^30 bytes)."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: global___DiskDriveType.ValueType = ...,
        size_gib: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "size_gib", b"size_gib", "type", b"type"]) -> None: ...

global___Disk = Disk



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClassAnnotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Property]:
        """Properties extracted by a specified model.

        For example, if you ask to evaluate the image quality,
        the service could return such properties as `good` and `bad`.
        """

    def __init__(
        self,
        *,
        properties: collections.abc.Iterable[global___Property] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["properties", b"properties"]) -> None: ...

global___ClassAnnotation = ClassAnnotation

@typing.final
class Property(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Property name."""
    probability: builtins.float
    """Probability of the property, from 0 to 1."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        probability: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "probability", b"probability"]) -> None: ...

global___Property = Property



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.searchapi.v2.img_search_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ImageSearchServiceStub:
    """A set of methods for searching of images using the Yandex Images."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Search: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse,
    ]

    SearchByImage: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse,
    ]

class ImageSearchServiceAsyncStub:
    """A set of methods for searching of images using the Yandex Images."""

    Search: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse,
    ]

    SearchByImage: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse,
    ]

class ImageSearchServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for searching of images using the Yandex Images."""

    @abc.abstractmethod
    def Search(
        self,
        request: yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse]]: ...

    @abc.abstractmethod
    def SearchByImage(
        self,
        request: yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse]]: ...

def add_ImageSearchServiceServicer_to_server(servicer: ImageSearchServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ApiKey(google.protobuf.message.Message):
    """An ApiKey resource. For more information, see [Api-Key](/docs/iam/concepts/authorization/api-key)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LAST_USED_AT_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the API Key."""
    service_account_id: builtins.str
    """ID of the service account that the API key belongs to."""
    description: builtins.str
    """Description of the API key. 0-256 characters long."""
    scope: builtins.str
    """Draft
    Scope of the API key. 0-256 characters long.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def last_used_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp for the last authentication using this API key."""

    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Scopes of the API key. 0-256 characters long."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """API key expiration timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        description: builtins.str = ...,
        last_used_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        scope: builtins.str = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "expires_at", b"expires_at", "last_used_at", b"last_used_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "expires_at", b"expires_at", "id", b"id", "last_used_at", b"last_used_at", "scope", b"scope", "scopes", b"scopes", "service_account_id", b"service_account_id"]) -> None: ...

global___ApiKey = ApiKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.refresh_token_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RefreshTokenServiceStub:
    """A set of methods for managing Refresh Tokens."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensRequest,
        yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensResponse,
    ]
    """List subjects Refresh Tokens."""

    Revoke: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.refresh_token_service_pb2.RevokeRefreshTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Revoke Refresh Tokens. Several Refresh Tokens can be revoked by one request."""

class RefreshTokenServiceAsyncStub:
    """A set of methods for managing Refresh Tokens."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensRequest,
        yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensResponse,
    ]
    """List subjects Refresh Tokens."""

    Revoke: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.refresh_token_service_pb2.RevokeRefreshTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Revoke Refresh Tokens. Several Refresh Tokens can be revoked by one request."""

class RefreshTokenServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Refresh Tokens."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.refresh_token_service_pb2.ListRefreshTokensResponse]]:
        """List subjects Refresh Tokens."""

    @abc.abstractmethod
    def Revoke(
        self,
        request: yandex.cloud.iam.v1.refresh_token_service_pb2.RevokeRefreshTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Revoke Refresh Tokens. Several Refresh Tokens can be revoked by one request."""

def add_RefreshTokenServiceServicer_to_server(servicer: RefreshTokenServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from concurrent import futures
from unittest.mock import Mock, patch

import grpc
import pytest

from yandex.cloud.vpc.v1.network_pb2 import Network
from yandex.cloud.vpc.v1.network_service_pb2 import GetNetworkRequest
from yandex.cloud.vpc.v1.network_service_pb2_grpc import (
    NetworkServiceStub,
    add_NetworkServiceServicer_to_server,
)
from yandexcloud import SDK, RetryPolicy, ThrottlingMode
from yandexcloud._channels import Channels

INSECURE_SERVICE_PORT = "50051"
SERVICE_ADDR = "localhost"


def side_effect_internal(_, context):
    context.set_code(grpc.StatusCode.INTERNAL)


def side_effect_unavailable(_, context):
    context.set_code(grpc.StatusCode.UNAVAILABLE)


class VPCServiceMock:
    def __init__(self, fn):
        self.Get = Mock(side_effect=fn)
        self.Create = Mock()
        self.Update = Mock()
        self.Delete = Mock()
        self.ListSubnets = Mock()
        self.ListSecurityGroups = Mock()
        self.ListRouteTables = Mock()
        self.ListOperations = Mock()
        self.Move = Mock()
        self.List = Mock()


@pytest.fixture
def mock_channel():
    with patch.multiple(
        Channels,
        _get_creds=lambda self, endpoint: grpc.local_channel_credentials(),
        _get_endpoints=lambda self: {
            "vpc": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
            "iam": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
        },
    ) as channel_patch:
        yield channel_patch


def grpc_server(side_effect):
    service = VPCServiceMock(side_effect)
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    server.add_insecure_port("localhost:" + INSECURE_SERVICE_PORT)
    add_NetworkServiceServicer_to_server(service, server)
    server.start()
    return server, service


def test_persistent_retries(mock_channel):
    server, service = grpc_server(side_effect_unavailable)

    sdk = SDK(
        retry_policy=RetryPolicy(throttling_mode=ThrottlingMode.PERSISTENT),
        endpoint=f"localhost:{INSECURE_SERVICE_PORT}",
        endpoints={
            "vpc": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
            "iam": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
        },
    )
    network_client = sdk.client(NetworkServiceStub, insecure=True)
    try:
        request = GetNetworkRequest(network_id="asdf")
        network_client.Get(request)
    except grpc.RpcError:
        assert service.Get.call_count == 4

    server.stop(0)


def test_custom_retries(mock_channel):
    server, service = grpc_server(side_effect_internal)

    sdk = SDK(
        retry_policy=RetryPolicy(status_codes=(grpc.StatusCode.INTERNAL,), max_attempts=4),
        endpoint=f"localhost:{INSECURE_SERVICE_PORT}",
        endpoints={
            "vpc": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
            "iam": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
        },
    )
    network_client = sdk.client(NetworkServiceStub, insecure=True)
    try:
        request = GetNetworkRequest(network_id="asdf")
        network_client.Get(request)
    except grpc.RpcError:
        # because of temporary throttling mode by default
        assert service.Get.call_count == 3

    server.stop(0)


def test_no_retries(mock_channel):
    server, service = grpc_server(side_effect_internal)

    sdk = SDK(
        endpoint=f"localhost:{INSECURE_SERVICE_PORT}",
        endpoints={
            "vpc": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
            "iam": SERVICE_ADDR + ":" + INSECURE_SERVICE_PORT,
        },
    )
    network_client = sdk.client(NetworkServiceStub, insecure=True)
    try:
        request = GetNetworkRequest(network_id="asdf")
        network_client.Get(request)
    except grpc.RpcError:
        assert service.Get.call_count == 1

    server.stop(0)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/configuration_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/configuration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.baremetal.v1alpha import configuration_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_configuration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/baremetal/v1alpha/configuration_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x32yandex/cloud/baremetal/v1alpha/configuration.proto\x1a\x1dyandex/cloud/validation.proto\"~\n\x17GetConfigurationRequest\x12\x32\n\x10\x63onfiguration_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12/\n\tfolder_id\x18\x02 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\"\xa6\x01\n\x19ListConfigurationsRequest\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\t\x12/\n\tfolder_id\x18h \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50J\x04\x08\x01\x10\x64\"\x82\x01\n\x1aListConfigurationsResponse\x12\x45\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32-.yandex.cloud.baremetal.v1alpha.Configuration\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xef\x02\n\x14\x43onfigurationService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.baremetal.v1alpha.GetConfigurationRequest\x1a-.yandex.cloud.baremetal.v1alpha.Configuration\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/baremetal/v1alpha/configurations/{configuration_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.baremetal.v1alpha.ListConfigurationsRequest\x1a:.yandex.cloud.baremetal.v1alpha.ListConfigurationsResponse\")\x82\xd3\xe4\x93\x02#\x12!/baremetal/v1alpha/configurationsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.configuration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETCONFIGURATIONREQUEST'].fields_by_name['configuration_id']._loaded_options = None
  _globals['_GETCONFIGURATIONREQUEST'].fields_by_name['configuration_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_GETCONFIGURATIONREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETCONFIGURATIONREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTCONFIGURATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCONFIGURATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTCONFIGURATIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCONFIGURATIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/baremetal/v1alpha/configurations/{configuration_id}'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/baremetal/v1alpha/configurations'
  _globals['_GETCONFIGURATIONREQUEST']._serialized_start=207
  _globals['_GETCONFIGURATIONREQUEST']._serialized_end=333
  _globals['_LISTCONFIGURATIONSREQUEST']._serialized_start=336
  _globals['_LISTCONFIGURATIONSREQUEST']._serialized_end=502
  _globals['_LISTCONFIGURATIONSRESPONSE']._serialized_start=505
  _globals['_LISTCONFIGURATIONSRESPONSE']._serialized_end=635
  _globals['_CONFIGURATIONSERVICE']._serialized_start=638
  _globals['_CONFIGURATIONSERVICE']._serialized_end=1005
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.loadtesting.api.v1.config import config_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2
from yandex.cloud.loadtesting.api.v1 import config_service_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/loadtesting/api/v1/config_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ConfigServiceStub(object):
    """A set of methods for managing test configurations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/Create',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.CreateConfigRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/Get',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.GetConfigRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2.Config.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/List',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/Delete',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.DeleteConfigRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class ConfigServiceServicer(object):
    """A set of methods for managing test configurations.
    """

    def Create(self, request, context):
        """Creates a test config in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified config.

        To get the list of all available configs, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of configs in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.CreateConfigRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.GetConfigRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2.Config.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.DeleteConfigRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.loadtesting.api.v1.ConfigService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.loadtesting.api.v1.ConfigService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ConfigService(object):
    """A set of methods for managing test configurations.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/Create',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.CreateConfigRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/Get',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.GetConfigRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2.Config.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/List',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/Delete',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.DeleteConfigRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
